@@ -7,6 +7,8 @@ import (
 	"os/exec"
 	"runtime"
 	"strconv"
+	"strings"
+	"time"
 )
 
 // toggleWrapMode toggles wrapMode each time it is called.
@@ -45,50 +47,101 @@ func (root *Root) toggleFollowAll() {
 	root.General.FollowAll = !root.General.FollowAll
 }
 
-// setDocument sets the Document.
-func (root *Root) setDocument(m *Document) {
-	root.Doc = m
-	root.ViewSync()
-}
-
-// helpDisplay is to switch between helpDisplay screen and normal screen.
-func (root *Root) helpDisplay() {
-	if root.screenMode == Help {
-		root.toNormal()
+// closeFile close the file.
+func (root *Root) closeFile() {
+	if root.screenMode != Docs {
 		return
 	}
-	root.setDocument(root.helpDoc)
-	root.screenMode = Help
-}
 
-// LogDisplay is to switch between Log screen and normal screen.
-func (root *Root) logDisplay() {
-	if root.screenMode == LogDoc {
-		root.toNormal()
+	if root.Doc.checkClose() {
+		root.setMessage("already closed")
 		return
 	}
-	root.setDocument(root.logDoc)
-	root.screenMode = LogDoc
+	if err := root.Doc.close(); err != nil {
+		log.Printf("closeFile: %s", err)
+	}
+	root.setMessagef("close file %s", root.Doc.FileName)
+	log.Printf("close file %s", root.Doc.FileName)
 }
 
-// toNormal displays a normal document.
-func (root *Root) toNormal() {
-	root.mu.RLock()
-	defer root.mu.RUnlock()
+func (root *Root) reload(m *Document) {
+	if m.preventReload {
+		root.setMessagef("cannot reload: %s", m.FileName)
+		return
+	}
 
-	root.setDocument(root.DocList[root.CurrentDoc])
-	root.screenMode = Docs
+	if err := m.reload(); err != nil {
+		log.Printf("cannot reload: %s", err)
+		return
+	}
+	time.Sleep(100 * time.Millisecond)
+}
+
+func (root *Root) watch() {
+	root.Doc.WatchMode = !root.Doc.WatchMode
+	if root.Doc.WatchMode {
+		root.watchStart()
+	}
+}
+
+func (root *Root) watchStart() {
+	m := root.Doc
+	m.WatchInterval = max(m.WatchInterval, 1)
+	if m.ticker != nil {
+		log.Println("watch stop")
+		m.ticker.Stop()
+	}
+	log.Printf("watch start at interval %d", m.WatchInterval)
+	m.ticker = time.NewTicker(time.Duration(m.WatchInterval) * time.Second)
+	go func() {
+		for {
+			<-m.ticker.C
+			if m.WatchMode {
+				ev := &eventReload{}
+				ev.SetEventNow()
+				ev.m = m
+				err := root.Screen.PostEvent(ev)
+				if err != nil {
+					log.Println(err)
+				}
+			} else {
+				log.Println("watch stop")
+				m.ticker.Stop()
+				return
+			}
+		}
+	}()
 }
 
 // goLine will move to the specified line.
 func (root *Root) goLine(input string) {
-	lN, err := strconv.Atoi(input)
+	if !strings.Contains(input, ".") {
+		// Line number only.
+		lN, err := strconv.Atoi(input)
+		if err != nil {
+			root.setMessage(ErrInvalidNumber.Error())
+			return
+		}
+		lN = root.moveLine(lN - 1)
+		root.setMessagef("Moved to line %d", lN+1)
+		return
+	}
+
+	// Line number and number of wrapping lines.
+	inputs := strings.Split(input, ".")
+	lN, err := strconv.Atoi(inputs[0])
 	if err != nil {
 		root.setMessage(ErrInvalidNumber.Error())
 		return
 	}
-	lN = root.moveLine(lN - 1)
-	root.setMessagef("Moved to line %d", lN+1)
+	log.Println(lN)
+	nTh, err := strconv.Atoi(inputs[1])
+	if err != nil {
+		root.setMessage(ErrInvalidNumber.Error())
+		return
+	}
+	lN, nTh = root.moveLineNth(lN-1, nTh)
+	root.setMessagef("Moved to line %d.%d", lN+1, nTh)
 }
 
 // goLineNumber moves to the specified line number.
@@ -192,79 +245,6 @@ func (root *Root) setSkipLines(input string) {
 	root.Doc.ClearCache()
 }
 
-// nextDoc displays the next document.
-func (root *Root) nextDoc() {
-	root.setDocumentNum(root.CurrentDoc + 1)
-	root.input.mode = Normal
-	root.debugMessage("next document")
-	root.debugMessage(fmt.Sprintf("cache %v\n", root.Doc.cache.Metrics.String()))
-}
-
-// previouseDoc displays the previous document.
-func (root *Root) previousDoc() {
-	root.setDocumentNum(root.CurrentDoc - 1)
-	root.input.mode = Normal
-	root.debugMessage("previous document")
-	root.debugMessage(fmt.Sprintf("cache %v\n", root.Doc.cache.Metrics.String()))
-}
-
-// switchDocument displays the document of the specified docNum.
-func (root *Root) switchDocument(docNum int) {
-	root.setDocumentNum(docNum)
-	root.debugMessage("switch document")
-	root.debugMessage(fmt.Sprintf("cache %v\n", root.Doc.cache.Metrics.String()))
-}
-
-// addDocument adds a document and displays it.
-func (root *Root) addDocument(m *Document) {
-	root.mu.Lock()
-	defer root.mu.Unlock()
-	root.setMessagef("add %s", m.FileName)
-	m.general = root.Config.General
-
-	root.DocList = append(root.DocList, m)
-	root.CurrentDoc = len(root.DocList) - 1
-
-	root.setDocument(m)
-}
-
-// closeDocument closes the document.
-// If there is only one document, do nothing.
-func (root *Root) closeDocument() {
-	if root.DocumentLen() == 1 {
-		return
-	}
-
-	root.mu.Lock()
-	defer root.mu.Unlock()
-
-	root.setMessagef("close [%d]%s", root.CurrentDoc, root.Doc.FileName)
-	root.DocList = append(root.DocList[:root.CurrentDoc], root.DocList[root.CurrentDoc+1:]...)
-	if root.CurrentDoc > 0 {
-		root.CurrentDoc--
-	}
-	doc := root.DocList[root.CurrentDoc]
-
-	root.setDocument(doc)
-}
-
-// setDocumentNum actually specifies docNum to display the document.
-// This function is called internally from next / previous / switch / add.
-func (root *Root) setDocumentNum(docNum int) {
-	root.mu.Lock()
-	defer root.mu.Unlock()
-
-	if docNum >= len(root.DocList) {
-		docNum = len(root.DocList) - 1
-	}
-	if docNum < 0 {
-		docNum = 0
-	}
-	root.CurrentDoc = docNum
-	m := root.DocList[root.CurrentDoc]
-	root.setDocument(m)
-}
-
 // suspend suspends the current screen display and runs the shell.
 // It will return when you exit the shell.
 func (root *Root) suspend() {
@@ -349,6 +329,57 @@ func (root *Root) setTabWidth(input string) {
 	root.Doc.ClearCache()
 }
 
+func (root *Root) setWatchInterval(input string) {
+	interval, err := strconv.Atoi(input)
+	if err != nil {
+		root.setMessage(ErrInvalidNumber.Error())
+		return
+	}
+	if root.Doc.WatchInterval == interval {
+		return
+	}
+
+	root.Doc.WatchInterval = interval
+	if root.Doc.WatchInterval == 0 {
+		root.Doc.WatchMode = false
+		return
+	}
+
+	root.Doc.WatchMode = true
+	root.watchStart()
+	root.setMessagef("Set watch interval %d", interval)
+}
+
+func (root *Root) setWriteBA(input string) {
+	ba := strings.Split(input, ":")
+	bstr := ba[0]
+	if bstr == "" {
+		bstr = "0"
+	}
+	before, err := strconv.Atoi(bstr)
+	if err != nil {
+		root.setMessage(ErrInvalidNumber.Error())
+		return
+	}
+	root.BeforeWriteOriginal = before
+
+	if len(ba) > 1 {
+		astr := ba[1]
+		if astr == "" {
+			astr = "0"
+		}
+		after, err := strconv.Atoi(astr)
+		if err != nil {
+			root.setMessage(ErrInvalidNumber.Error())
+			return
+		}
+		root.AfterWriteOriginal = after
+	}
+	root.debugMessage(fmt.Sprintf("Before:After:%d:%d", root.BeforeWriteOriginal, root.AfterWriteOriginal))
+	root.IsWriteOriginal = true
+	root.Quit()
+}
+
 // resize is a wrapper function that calls viewSync.
 func (root *Root) resize() {
 	root.ViewSync()
