@@ -1,9 +1,13 @@
 package oviewer
 
 import (
+	"context"
+	"fmt"
+	"io"
 	"os"
 	"sync"
 	"sync/atomic"
+	"time"
 
 	"github.com/dgraph-io/ristretto"
 )
@@ -13,6 +17,8 @@ import (
 type Document struct {
 	// fileName is the file name to display.
 	FileName string
+	// Caption is an additional caption to display after the file name.
+	Caption string
 
 	// File is the os.File.
 	file *os.File
@@ -21,6 +27,11 @@ type Document struct {
 	// CFormat is a compressed format.
 	CFormat Compressed
 
+	// preventReload is true to prevent reload.
+	preventReload bool
+	// Is it possible to seek.
+	seekable bool
+
 	// lines stores the contents of the file in slices of strings.
 	// lines,endNum and eof is updated by reader goroutine.
 	lines []string
@@ -32,16 +43,18 @@ type Document struct {
 	// notify when eof is reached.
 	eofCh chan struct{}
 	// notify when reopening.
-	reOpenCh chan struct{}
-	// reOpened represents the reOpen file.
-	reOpened sync.Once
+	followCh chan struct{}
+	// openFollow represents the open followMode file.
+	openFollow int32
 
 	// 1 if there is a changed.
 	changed int32
 	// notify when a file changes.
 	changCh chan struct{}
-	// notify close document.
-	closeCh chan struct{}
+
+	cancel context.CancelFunc
+	// 1 if there is a closed.
+	closed int32
 
 	// cache represents a cache of contents.
 	cache *ristretto.Cache
@@ -53,12 +66,21 @@ type Document struct {
 	// status is the display status of the document.
 	general
 
+	// WatchMode is watch mode.
+	WatchMode bool
+	ticker    *time.Ticker
+
 	// latestNum is the endNum read at the end of the screen update.
 	latestNum int
 	// topLN is the starting position of the current y.
 	topLN int
 	// topLX represents the x position of the top line.
 	topLX int
+	// bottomLN is the last line number displayed.
+	bottomLN int
+	// bottomLX is the leftmost X position on the last line.
+	bottomLX int
+
 	// x is the starting position of the current x.
 	x int
 	// columnNum is the number of columns.
@@ -77,15 +99,16 @@ func NewDocument() (*Document, error) {
 	m := &Document{
 		lines:    make([]string, 0),
 		eofCh:    make(chan struct{}),
-		reOpenCh: make(chan struct{}),
+		followCh: make(chan struct{}),
 		changCh:  make(chan struct{}),
-		closeCh:  make(chan struct{}),
 		general: general{
 			ColumnDelimiter: "",
 			TabWidth:        8,
 			MarkStyleWidth:  1,
 		},
 		lastContentsNum: -1,
+		seekable:        true,
+		preventReload:   false,
 	}
 
 	if err := m.NewCache(); err != nil {
@@ -98,12 +121,27 @@ func NewDocument() (*Document, error) {
 func (m *Document) GetLine(n int) string {
 	m.mu.Lock()
 	defer m.mu.Unlock()
-	if n < 0 || n >= len(m.lines) {
+	if n < 0 || n >= m.endNum {
 		return ""
 	}
 	return m.lines[n]
 }
 
+// CurrentLN returns the currently displayed line number.
+func (m *Document) CurrentLN() int {
+	return m.topLN
+}
+
+// Export exports the document in the specified range.
+func (m *Document) Export(w io.Writer, start int, end int) {
+	for n := start; n <= end; n++ {
+		if n >= m.BufEndNum() {
+			break
+		}
+		fmt.Fprintln(w, m.GetLine(n))
+	}
+}
+
 // BufEndNum return last line number.
 func (m *Document) BufEndNum() int {
 	m.mu.Lock()
@@ -141,9 +179,9 @@ func (m *Document) contentsLN(lN int, tabWidth int) (lineContents, error) {
 		return nil, ErrOutOfRange
 	}
 
-	value, found := m.cache.Get(lN)
-	// It was cached.
-	if found {
+	key := fmt.Sprintf("contents:%d", lN)
+	if value, found := m.cache.Get(key); found {
+		// It was cached.
 		lc, ok := value.(lineContents)
 		if !ok {
 			return lc, ErrFatalCache
@@ -152,8 +190,9 @@ func (m *Document) contentsLN(lN int, tabWidth int) (lineContents, error) {
 	}
 
 	// It wasn't cached.
-	lc := parseString(m.GetLine(lN), tabWidth)
-	m.cache.Set(lN, lc, 1)
+	str := m.GetLine(lN)
+	lc := parseString(str, tabWidth)
+	m.cache.Set(key, lc, 1)
 	return lc, nil
 }
 
