@@ -15,7 +15,7 @@ func (root *Root) draw() {
 	m := root.Doc
 
 	root.Screen.Clear()
-	if m.BufEndNum() == 0 || root.vHight == 0 {
+	if root.vHight == 0 {
 		m.topLN = 0
 		root.statusDraw()
 		root.Show()
@@ -35,8 +35,8 @@ func (root *Root) draw() {
 	// Body
 	lX, lY = root.drawBody(lX, lY)
 
-	root.bottomLN = m.topLN + max(lY, 0)
-	root.bottomLX = lX
+	m.bottomLN = m.topLN + max(lY, 0)
+	m.bottomLX = lX
 
 	if root.mouseSelect {
 		root.drawSelect(root.x1, root.y1, root.x2, root.y2, true)
@@ -74,8 +74,8 @@ func (root *Root) drawHeader() int {
 
 		// line number mode
 		if m.LineNumMode {
-			lc := StrToContents(strings.Repeat(" ", root.startX-1), m.TabWidth)
-			root.setContentString(0, hy, lc)
+			numC := StrToContents(strings.Repeat(" ", root.startX-1), m.TabWidth)
+			root.setContentString(0, hy, numC)
 		}
 
 		root.lnumber[hy] = lineNumber{
@@ -109,7 +109,7 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 
 	listX, err := root.leftMostX(m.topLN + root.Doc.firstLine() + lY)
 	if err != nil {
-		log.Printf("drawBody %d:%s", m.topLN+lY, err)
+		root.debugMessage(fmt.Sprintf("drawBody %d:%s", m.topLN+lY, err))
 	}
 	wrap := numOfSlice(listX, lX)
 
@@ -144,12 +144,7 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 
 		// search highlight
 		if root.searchWord != "" {
-			var poss [][]int
-			if root.Config.RegexpSearch {
-				poss = searchPositionReg(lineStr, root.searchReg)
-			} else {
-				poss = searchPosition(root.Config.CaseSensitive, lineStr, root.searchWord)
-			}
+			poss := root.searchPosition(m.topLN+lY, lineStr)
 			for _, r := range poss {
 				root.searchHighlight(lc, posCV[r[0]], posCV[r[1]])
 			}
@@ -157,11 +152,11 @@ func (root *Root) drawBody(lX int, lY int) (int, int) {
 
 		// line number mode
 		if m.LineNumMode {
-			lc := StrToContents(fmt.Sprintf("%*d", root.startX-1, m.topLN+lY-m.firstLine()+1), m.TabWidth)
-			for i := 0; i < len(lc); i++ {
-				lc[i].style = applyStyle(tcell.StyleDefault, root.StyleLineNumber)
+			numC := StrToContents(fmt.Sprintf("%*d", root.startX-1, m.topLN+lY-m.firstLine()+1), m.TabWidth)
+			for i := 0; i < len(numC); i++ {
+				numC[i].style = applyStyle(tcell.StyleDefault, root.StyleLineNumber)
 			}
-			root.setContentString(0, y, lc)
+			root.setContentString(0, y, numC)
 		}
 
 		root.lnumber[y] = lineNumber{
@@ -298,14 +293,25 @@ func (root *Root) normalLeftStatus() (lineContents, int) {
 	if root.DocumentLen() > 1 && root.screenMode == Docs {
 		number = fmt.Sprintf("[%d]", root.CurrentDoc)
 	}
-	follow := ""
+	modeStatus := ""
 	if root.Doc.FollowMode {
-		follow = "(Follow Mode)"
+		modeStatus = "(Follow Mode)"
 	}
 	if root.General.FollowAll {
-		follow = "(Follow All)"
+		modeStatus = "(Follow All)"
 	}
-	leftStatus := fmt.Sprintf("%s%s%s:%s", number, follow, root.Doc.FileName, root.message)
+	if root.Doc.WatchMode {
+		modeStatus += "(Watch)"
+	}
+
+	caption := ""
+	if root.Doc.Caption != "" {
+		caption = root.Doc.Caption
+	} else {
+		caption = root.Doc.FileName
+	}
+
+	leftStatus := fmt.Sprintf("%s%s%s:%s", number, modeStatus, caption, root.message)
 	leftContents := StrToContents(leftStatus, -1)
 	color := tcell.ColorWhite
 	if root.CurrentDoc != 0 {
