@@ -5,15 +5,20 @@ import (
 	"fmt"
 	"log"
 	"strconv"
-	"sync/atomic"
 	"time"
 
 	"code.rocketnine.space/tslocum/cbind"
 	"github.com/gdamore/tcell/v2"
 )
 
+// UpdateInterval is the update interval that calls eventUpdate().
+var UpdateInterval time.Duration = 50
+
 // main is manages and executes events in the main routine.
 func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
+	if root.Doc.WatchMode {
+		root.watchStart()
+	}
 	go root.updateInterval(ctx)
 
 	for {
@@ -35,6 +40,8 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 			}
 			close(quitChan)
 			return
+		case *eventReload:
+			root.reload(ev.m)
 		case *eventAppSuspend:
 			root.suspend()
 		case *eventUpdateEndNum:
@@ -73,6 +80,10 @@ func (root *Root) main(ctx context.Context, quitChan chan<- struct{}) {
 			root.setDelimiter(ev.value)
 		case *tabWidthInput:
 			root.setTabWidth(ev.value)
+		case *watchIntervalInput:
+			root.setWatchInterval(ev.value)
+		case *writeBAInput:
+			root.setWriteBA(ev.value)
 		case *tcell.EventResize:
 			root.resize()
 		case *tcell.EventMouse:
@@ -146,7 +157,7 @@ func (root *Root) Cancel() {
 
 // WriteQuit sets the write flag and executes a quit event.
 func (root *Root) WriteQuit() {
-	root.AfterWrite = true
+	root.IsWriteOriginal = true
 	root.Quit()
 }
 
@@ -161,7 +172,7 @@ func (root *Root) follow() {
 		root.followAll()
 	}
 
-	root.onceFollowMode(root.Doc)
+	root.Doc.onceFollowMode()
 
 	num := root.Doc.BufEndNum()
 	if root.Doc.latestNum == num {
@@ -184,7 +195,7 @@ func (root *Root) followAll() {
 
 	root.mu.RLock()
 	for n, doc := range root.DocList {
-		root.onceFollowMode(doc)
+		doc.onceFollowMode()
 		if doc.latestNum != doc.BufEndNum() {
 			current = n
 		}
@@ -198,16 +209,9 @@ func (root *Root) followAll() {
 	}
 }
 
-// onceFollowMode is executed only once as follow mode.
-func (root *Root) onceFollowMode(doc *Document) {
-	doc.reOpened.Do(func() {
-		go doc.openFollowMode()
-	})
-}
-
 // updateInterval calls eventUpdate at regular intervals.
 func (root *Root) updateInterval(ctx context.Context) {
-	timer := time.NewTicker(time.Millisecond * 100)
+	timer := time.NewTicker(time.Millisecond * UpdateInterval)
 	for {
 		select {
 		case <-timer.C:
@@ -223,18 +227,8 @@ func (root *Root) eventUpdate() {
 	if !root.checkScreen() {
 		return
 	}
-	eventFlag := false
 
-	root.mu.RLock()
-	for _, doc := range root.DocList {
-		if atomic.LoadInt32(&doc.changed) == 1 {
-			eventFlag = true
-			atomic.StoreInt32(&doc.changed, 0)
-		}
-	}
-	root.mu.RUnlock()
-
-	if !eventFlag {
+	if !root.hasDocChanged() {
 		return
 	}
 
@@ -454,3 +448,25 @@ func (root *Root) cancelWait() error {
 		}
 	}
 }
+
+// eventReload represents a reload event.
+type eventReload struct {
+	m *Document
+	tcell.EventTime
+}
+
+// Reload executes a reload event.
+func (root *Root) Reload() {
+	if !root.checkScreen() {
+		return
+	}
+	root.setMessagef("reload %s", root.Doc.FileName)
+	log.Printf("reload %s", root.Doc.FileName)
+	ev := &eventReload{}
+	ev.SetEventNow()
+	ev.m = root.Doc
+	err := root.Screen.PostEvent(ev)
+	if err != nil {
+		log.Println(err)
+	}
+}
