@@ -23,6 +23,8 @@ type Input struct {
 	GoCandidate        *candidate
 	DelimiterCandidate *candidate
 	TabWidthCandidate  *candidate
+	WatchCandidate     *candidate
+	WriteBACandidate   *candidate
 }
 
 // InputMode represents the state of the input.
@@ -45,8 +47,12 @@ const (
 	Delimiter
 	// TabWidth is the tab number input mode.
 	TabWidth
+	// WatchInterval is the watch interval input mode.
+	Watch
 	// SkipLines is the number of lines to skip.
 	SkipLines
+	// WriteBA is the number of ranges to write at quit.
+	WriteBA
 )
 
 // InputEvent input key events.
@@ -241,9 +247,21 @@ func NewInput() *Input {
 			"8",
 		},
 	}
+	i.WatchCandidate = &candidate{
+		list: []string{
+			"3",
+			"2",
+			"1",
+		},
+	}
 	i.SearchCandidate = &candidate{
 		list: []string{},
 	}
+	i.WriteBACandidate = &candidate{
+		list: []string{
+			":",
+		},
+	}
 	i.EventInput = &normalInput{}
 	return &i
 }
@@ -306,6 +324,22 @@ func (root *Root) setTabWidthMode() {
 	input.EventInput = newTabWidthInput(input.TabWidthCandidate)
 }
 
+func (root *Root) setWatchIntervalMode() {
+	input := root.input
+	input.value = ""
+	input.cursorX = 0
+	input.mode = Watch
+	input.EventInput = newWatchIntevalInput(input.WatchCandidate)
+}
+
+func (root *Root) setWriteBAMode() {
+	input := root.input
+	input.value = ""
+	input.cursorX = 0
+	input.mode = WriteBA
+	input.EventInput = newWriteBAInput(input.WriteBACandidate)
+}
+
 func (root *Root) setGoLineMode() {
 	input := root.input
 	input.value = ""
@@ -654,6 +688,78 @@ func (t *tabWidthInput) Down(str string) string {
 	return t.clist.down()
 }
 
+// watchIntervalInput represents the WatchInteval input mode.
+type watchIntervalInput struct {
+	value string
+	clist *candidate
+	tcell.EventTime
+}
+
+// newWatchIntevalInputt returns WatchIntevalInput.
+func newWatchIntevalInput(clist *candidate) *watchIntervalInput {
+	return &watchIntervalInput{clist: clist}
+}
+
+// Prompt returns the prompt string in the input field.
+func (t *watchIntervalInput) Prompt() string {
+	return "Watch interval:"
+}
+
+// Confirm returns the event when the input is confirmed.
+func (t *watchIntervalInput) Confirm(str string) tcell.Event {
+	t.value = str
+	t.clist.list = toLast(t.clist.list, str)
+	t.clist.p = 0
+	t.SetEventNow()
+	return t
+}
+
+// Up returns strings when the up key is pressed during input.
+func (t *watchIntervalInput) Up(str string) string {
+	return t.clist.up()
+}
+
+// Down returns strings when the down key is pressed during input.
+func (t *watchIntervalInput) Down(str string) string {
+	return t.clist.down()
+}
+
+// writeBAInput represents the WatchInteval input mode.
+type writeBAInput struct {
+	value string
+	clist *candidate
+	tcell.EventTime
+}
+
+// newWatchIntevalInputt returns WatchIntevalInput.
+func newWriteBAInput(clist *candidate) *writeBAInput {
+	return &writeBAInput{clist: clist}
+}
+
+// Prompt returns the prompt string in the input field.
+func (t *writeBAInput) Prompt() string {
+	return "WriteAndQuit Before:After:"
+}
+
+// Confirm returns the event when the input is confirmed.
+func (t *writeBAInput) Confirm(str string) tcell.Event {
+	t.value = str
+	t.clist.list = toLast(t.clist.list, str)
+	t.clist.p = 0
+	t.SetEventNow()
+	return t
+}
+
+// Up returns strings when the up key is pressed during input.
+func (t *writeBAInput) Up(str string) string {
+	return t.clist.up()
+}
+
+// Down returns strings when the down key is pressed during input.
+func (t *writeBAInput) Down(str string) string {
+	return t.clist.down()
+}
+
 func (c *candidate) up() string {
 	if len(c.list) == 0 {
 		return ""
