@@ -10,12 +10,17 @@ import (
 
 const (
 	actionExit           = "exit"
+	actionWriteBA        = "set_write_exit"
 	actionCancel         = "cancel"
 	actionWriteExit      = "write_exit"
 	actionSuspend        = "suspend"
 	actionSync           = "sync"
 	actionFollow         = "follow_mode"
 	actionFollowAll      = "follow_all"
+	actionCloseFile      = "close_file"
+	actionReload         = "reload"
+	actionWatch          = "watch"
+	actionWatchInterval  = "watch_interval"
 	actionHelp           = "help"
 	actionLogDoc         = "logdoc"
 	actionMoveDown       = "down"
@@ -62,12 +67,17 @@ const (
 func (root *Root) setHandler() map[string]func() {
 	return map[string]func(){
 		actionExit:           root.Quit,
+		actionWriteBA:        root.setWriteBAMode,
 		actionCancel:         root.Cancel,
 		actionWriteExit:      root.WriteQuit,
 		actionSuspend:        root.suspend,
 		actionSync:           root.ViewSync,
 		actionFollow:         root.toggleFollowMode,
 		actionFollowAll:      root.toggleFollowAll,
+		actionReload:         root.Reload,
+		actionWatch:          root.watch,
+		actionWatchInterval:  root.setWatchIntervalMode,
+		actionCloseFile:      root.closeFile,
 		actionHelp:           root.helpDisplay,
 		actionLogDoc:         root.logDisplay,
 		actionMoveDown:       root.moveDown,
@@ -118,13 +128,18 @@ type KeyBind map[string][]string
 func GetKeyBinds(bind map[string][]string) map[string][]string {
 	keyBind := map[string][]string{
 		actionExit:           {"Escape", "q"},
+		actionWriteBA:        {"ctrl+q"},
 		actionCancel:         {"ctrl+c"},
 		actionWriteExit:      {"Q"},
 		actionSync:           {"ctrl+l"},
 		actionFollow:         {"ctrl+f"},
 		actionFollowAll:      {"ctrl+a"},
-		actionHelp:           {"h"},
-		actionLogDoc:         {"ctrl+alt+e"},
+		actionCloseFile:      {"ctrl+F9", "ctrl+alt+s"},
+		actionReload:         {"F5", "ctrl+alt+l"},
+		actionWatch:          {"F4", "ctrl+alt+w"},
+		actionWatchInterval:  {"ctrl+w"},
+		actionHelp:           {"h", "ctrl+f1", "ctrl+alt+c"},
+		actionLogDoc:         {"ctrl+f2", "ctrl+alt+e"},
 		actionMoveDown:       {"Enter", "Down", "ctrl+N"},
 		actionMoveUp:         {"Up", "ctrl+p"},
 		actionMoveTop:        {"Home"},
