@@ -5,11 +5,11 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"io/fs"
 	"log"
 	"os"
 	"os/signal"
 	"regexp"
-	"strings"
 	"sync"
 	"syscall"
 
@@ -94,11 +94,6 @@ type Root struct {
 	// headerLen is the actual header length when wrapped.
 	headerLen int
 
-	// bottomLN is the last line number displayed.
-	bottomLN int
-	// bottomLX is the leftmost X position on the last line.
-	bottomLX int
-
 	// statusPos is the position of the status line.
 	statusPos int
 	// minStartX is the minimum start position of x.
@@ -123,20 +118,22 @@ type general struct {
 	Header int
 	// SkipLines is the rows to skip.
 	SkipLines int
-	// Color to alternate rows
+	// AlternateRows alternately style rows.
 	AlternateRows bool
-	// Column mode
+	// ColumnMode is column mode.
 	ColumnMode bool
-	// Line Number
+	// LineNumMode displays line numbers.
 	LineNumMode bool
 	// Wrap is Wrap mode.
 	WrapMode bool
-	// Column Delimiter
+	// ColumnDelimiter is a column delimiter.
 	ColumnDelimiter string
-	// Follow mode.
+	// FollowMode is the follow mode.
 	FollowMode bool
-	// Follow all.
+	// FollowAll is a follow mode for all documents.
 	FollowAll bool
+	// WatchInterval is the watch interval (seconds).
+	WatchInterval int
 	// MarkStyleWidth is width to apply the style of the marked line.
 	MarkStyleWidth int
 }
@@ -179,8 +176,15 @@ type Config struct {
 
 	// Mouse support disable.
 	DisableMouse bool
-	// AfterWrite writes the current screen on exit.
-	AfterWrite bool
+	// IsWriteOriginal is true, write the current screen on quit.
+	IsWriteOriginal bool
+	// BeforeWriteOriginal specifies the number of lines before the current position.
+	// 0 is the top of the current screen
+	BeforeWriteOriginal int
+	// AfterWriteOriginal specifies the number of lines after the current position.
+	// 0 specifies the bottom of the screen.
+	AfterWriteOriginal int
+
 	// QuiteSmall Quit if the output fits on one screen.
 	QuitSmall bool
 	// CaseSensitive is case-sensitive if true.
@@ -247,6 +251,8 @@ const (
 	LogDoc
 )
 
+const MaxWriteLog int = 10
+
 var (
 	// ErrOutOfRange indicates that value is out of range.
 	ErrOutOfRange = errors.New("out of range")
@@ -266,6 +272,8 @@ var (
 	ErrFailedKeyBind = errors.New("failed to set keybind")
 	// ErrSignalCatch indicates that the signal has been caught.
 	ErrSignalCatch = errors.New("signal catch")
+	// ErrAlreadyClose indicates that it is already closed.
+	ErrAlreadyClose = errors.New("already closed")
 )
 
 // This is a function of tcell.NewScreen but can be replaced with mock.
@@ -393,6 +401,7 @@ func openSTDIN() (*Root, error) {
 		return nil, err
 	}
 
+	m.seekable = false
 	if err := m.ReadFile(""); err != nil {
 		return nil, err
 	}
@@ -412,6 +421,10 @@ func openFile(fileName string) (*Document, error) {
 	if err != nil {
 		return nil, err
 	}
+
+	if fi.Mode()&fs.ModeNamedPipe != 0 {
+		m.seekable = false
+	}
 	if err := m.ReadFile(fileName); err != nil {
 		return nil, err
 	}
@@ -538,7 +551,7 @@ func (root *Root) Run() error {
 	// Call from man command.
 	manPN := os.Getenv("MAN_PN")
 	if len(manPN) > 0 {
-		root.Doc.FileName = manPN
+		root.Doc.Caption = manPN
 		// Bug?? Clipboard fails when called by man.
 		root.Screen.DisableMouse()
 	}
@@ -546,8 +559,10 @@ func (root *Root) Run() error {
 	for n, doc := range root.DocList {
 		log.Printf("open [%d]%s", n, doc.FileName)
 		doc.general = root.Config.General
+		if doc.general.WatchInterval > 0 {
+			doc.WatchMode = true
+		}
 	}
-	root.setGlobalStyle()
 	root.Screen.Clear()
 
 	list := make([]string, 0, len(root.Config.Mode)+1)
@@ -560,7 +575,7 @@ func (root *Root) Run() error {
 	root.ViewSync()
 	// Exit if fits on screen
 	if root.QuitSmall && root.docSmall() {
-		root.AfterWrite = true
+		root.IsWriteOriginal = true
 		return nil
 	}
 
@@ -626,7 +641,7 @@ func (root *Root) debugMessage(msg string) {
 	log.Printf("%s:%s", root.Doc.FileName, msg)
 }
 
-func setStyle(s ovStyle) tcell.Style {
+func ToTcellStyle(s ovStyle) tcell.Style {
 	style := tcell.StyleDefault
 	style = style.Background(tcell.GetColor(s.Background))
 	style = style.Foreground(tcell.GetColor(s.Foreground))
@@ -672,28 +687,6 @@ func applyStyle(style tcell.Style, s ovStyle) tcell.Style {
 	return style
 }
 
-func (root *Root) setGlobalStyle() {
-	OverStrikeStyle = setStyle(root.Config.StyleOverStrike)
-	OverLineStyle = setStyle(root.Config.StyleOverLine)
-	root.setOldGlobalStyle()
-}
-
-// setGlobalStyle sets some styles that are determined by the settings.
-func (root *Root) setOldGlobalStyle() {
-	if root.ColorAlternate != "" {
-		root.StyleAlternate = ovStyle{Background: root.ColorAlternate}
-	}
-	if root.ColorHeader != "" {
-		root.StyleHeader = ovStyle{Foreground: root.ColorHeader}
-	}
-	if root.ColorOverStrike != "" {
-		OverStrikeStyle = OverStrikeStyle.Foreground(tcell.GetColor(root.ColorOverStrike))
-	}
-	if root.ColorOverLine != "" {
-		OverLineStyle = OverLineStyle.Foreground(tcell.GetColor(root.ColorOverLine))
-	}
-}
-
 // prepareView prepares when the screen size is changed.
 func (root *Root) prepareView() {
 	screen := root.Screen
@@ -735,38 +728,25 @@ func (root *Root) docSmall() bool {
 // WriteOriginal writes to the original terminal.
 func (root *Root) WriteOriginal() {
 	m := root.Doc
-	p := 0
-	for n := m.topLN; ; n++ {
-		if n >= m.BufEndNum() {
-			break
-		}
-
-		lc, err := m.contentsLN(n, root.Doc.TabWidth)
-		if err != nil {
-			log.Println(err, n)
-			continue
-		}
-		p += 1 + (len(lc) / root.vWidth)
-		if p >= root.vHight {
-			break
-		}
-
-		fmt.Println(m.GetLine(n))
+	if m.bottomLN == 0 {
+		m.bottomLN = m.BufEndNum()
 	}
+
+	start := max(0, m.topLN-root.BeforeWriteOriginal)
+	end := m.bottomLN - 1
+	if root.AfterWriteOriginal != 0 {
+		end = m.topLN + root.AfterWriteOriginal - 1
+	}
+
+	m.Export(os.Stdout, start, end)
 }
 
 // WriteLog write to the log terminal.
 func (root *Root) WriteLog() {
-	maxWriteLog := 10
 	m := root.logDoc
-
-	n := m.BufEndNum() - maxWriteLog
-	for i := 0; i < maxWriteLog; i++ {
-		str := strings.ReplaceAll(m.GetLine(n+i), "\n", "")
-		if len(str) > 0 {
-			fmt.Fprintln(os.Stderr, str)
-		}
-	}
+	start := max(0, m.BufEndNum()-MaxWriteLog)
+	end := m.BufEndNum()
+	m.Export(os.Stdout, start, end)
 }
 
 // leftMostX returns a list of left - most x positions when wrapping.
@@ -788,10 +768,3 @@ func (root *Root) leftMostX(lN int) ([]int, error) {
 	}
 	return listX, nil
 }
-
-// DocumentLen returns the number of Docs.
-func (root *Root) DocumentLen() int {
-	root.mu.RLock()
-	defer root.mu.RUnlock()
-	return len(root.DocList)
-}
