@@ -5,6 +5,7 @@ import (
 	"bytes"
 	"compress/bzip2"
 	"compress/gzip"
+	"context"
 	"errors"
 	"fmt"
 	"io"
@@ -129,9 +130,13 @@ func (m *Document) ReadFile(fileName string) error {
 
 	go func() {
 		<-m.eofCh
-		m.close()
+		if m.seekable {
+			if err := m.close(); err != nil {
+				log.Printf("ReadFile: %s", err)
+			}
+		}
 		atomic.StoreInt32(&m.changed, 1)
-		close(m.reOpenCh)
+		m.followCh <- struct{}{}
 	}()
 	if STDOUTPIPE != nil {
 		reader = io.TeeReader(reader, STDOUTPIPE)
@@ -140,48 +145,77 @@ func (m *Document) ReadFile(fileName string) error {
 	return m.ReadAll(reader)
 }
 
-// openFollowMode opens the file in follow mode.
+// onceFollowMode opens the follow mode only once.
+func (m *Document) onceFollowMode() {
+	if atomic.SwapInt32(&m.openFollow, 1) == 1 {
+		return
+	}
+	ctx := context.Background()
+	ctx, m.cancel = context.WithCancel(ctx)
+	go m.startFollowMode(ctx)
+}
+
+// startFollowMode opens the file in follow mode.
 // Seek to the position where the file was closed, and then read.
-func (m *Document) openFollowMode() {
+func (m *Document) startFollowMode(ctx context.Context) {
 	if m.file == nil {
 		return
 	}
-	<-m.reOpenCh
-	<-m.changCh
 
-	log.Printf("reopen %s", m.FileName)
+	<-m.followCh
+	if m.seekable {
+		// Wait for the file to open until it changes.
+		select {
+		case <-ctx.Done():
+			log.Println("follow mode cancel")
+			return
+		case <-m.changCh:
+		}
+		m.file = m.openFollowFile()
+	}
+
+	r := compressedFormatReader(m.CFormat, m.file)
+	if err := m.ContinueReadAll(ctx, r); err != nil {
+		log.Printf("%s follow mode read %v", m.FileName, err)
+	}
+}
+
+func (m *Document) openFollowFile() *os.File {
+	m.mu.Lock()
+	defer m.mu.Unlock()
 	r, err := os.Open(m.FileName)
 	if err != nil {
-		log.Printf("reopen %s", err)
-		return
+		log.Printf("openFollowFile: %s", err)
+		return m.file
 	}
-	m.mu.Lock()
-	m.file = r
-	m.mu.Unlock()
+	atomic.StoreInt32(&m.closed, 0)
 	atomic.StoreInt32(&m.eof, 0)
-
 	if _, err := r.Seek(m.offset, io.SeekStart); err != nil {
-		log.Printf("seek %s", err)
-		return
-	}
-
-	rr := compressedFormatReader(m.CFormat, r)
-	if err := m.ContinueReadAll(rr); err != nil {
-		log.Printf("%s cannot be reopened %v", m.FileName, err)
+		log.Printf("openFollowMode: %s", err)
 	}
+	return r
 }
 
 // Close closes the File.
 // Record the last read position.
 func (m *Document) close() error {
-	pos, err := m.file.Seek(0, io.SeekCurrent)
-	if err != nil {
-		return fmt.Errorf("seek: %w", err)
+	if m.checkClose() {
+		return nil
+	}
+
+	if m.seekable {
+		pos, err := m.file.Seek(0, io.SeekCurrent)
+		if err != nil {
+			return fmt.Errorf("close: %w", err)
+		}
+		m.offset = pos
 	}
-	m.offset = pos
 	if err := m.file.Close(); err != nil {
-		return fmt.Errorf("close(): %w", err)
+		return fmt.Errorf("close: %w", err)
 	}
+	atomic.StoreInt32(&m.openFollow, 0)
+	atomic.StoreInt32(&m.closed, 1)
+	atomic.StoreInt32(&m.changed, 1)
 	return nil
 }
 
@@ -197,7 +231,7 @@ func (m *Document) ReadAll(r io.Reader) error {
 
 		if err := m.readAll(reader); err != nil {
 			if errors.Is(err, io.EOF) || errors.Is(err, io.ErrClosedPipe) || errors.Is(err, os.ErrClosed) {
-				close(m.eofCh)
+				m.eofCh <- struct{}{}
 				atomic.StoreInt32(&m.eof, 1)
 				return
 			}
@@ -206,13 +240,23 @@ func (m *Document) ReadAll(r io.Reader) error {
 			return
 		}
 	}()
+
+	// Named pipes for continuous read.
+	if !m.seekable {
+		m.onceFollowMode()
+	}
 	return nil
 }
 
 // ContinueReadAll continues to read even if it reaches EOF.
-func (m *Document) ContinueReadAll(r io.Reader) error {
+func (m *Document) ContinueReadAll(ctx context.Context, r io.Reader) error {
 	reader := bufio.NewReader(r)
 	for {
+		select {
+		case <-ctx.Done():
+			return ctx.Err()
+		default:
+		}
 		if m.checkClose() {
 			return nil
 		}
@@ -231,10 +275,6 @@ func (m *Document) readAll(reader *bufio.Reader) error {
 	var line strings.Builder
 
 	for {
-		if m.checkClose() {
-			return nil
-		}
-
 		buf, isPrefix, err := reader.ReadLine()
 		if err != nil {
 			return err
@@ -249,20 +289,51 @@ func (m *Document) readAll(reader *bufio.Reader) error {
 	}
 }
 
-func (m *Document) append(line string) {
+func (m *Document) reload() error {
+	if (m.file == os.Stdin && m.BufEOF()) || !m.seekable && m.checkClose() {
+		return fmt.Errorf("%w %s", ErrAlreadyClose, m.FileName)
+	}
+
+	if m.seekable {
+		if m.cancel != nil {
+			m.cancel()
+		}
+		if !m.checkClose() && m.file != nil {
+			if err := m.close(); err != nil {
+				log.Println(err)
+			}
+		}
+	}
+
+	m.reset()
+
+	if !m.seekable {
+		return nil
+	}
+
+	atomic.StoreInt32(&m.closed, 0)
+	return m.ReadFile(m.FileName)
+}
+
+func (m *Document) append(lines ...string) {
 	m.mu.Lock()
-	m.lines = append(m.lines, line)
-	m.endNum++
+	for _, line := range lines {
+		m.lines = append(m.lines, line)
+		m.endNum++
+	}
 	m.mu.Unlock()
 	atomic.StoreInt32(&m.changed, 1)
 }
 
+func (m *Document) reset() {
+	m.mu.Lock()
+	m.endNum = 0
+	m.lines = m.lines[:0]
+	m.mu.Unlock()
+	atomic.StoreInt32(&m.changed, 1)
+	m.ClearCache()
+}
+
 func (m *Document) checkClose() bool {
-	select {
-	case <-m.closeCh:
-		log.Printf("document closed %s", m.FileName)
-		return true
-	default:
-	}
-	return false
+	return atomic.LoadInt32(&m.closed) == 1
 }
